@@ -5,6 +5,8 @@
 
 pub mod command;
 mod errors;
+#[cfg(feature = "lsp")]
+mod language_server;
 pub mod nodes;
 #[deny(missing_docs)]
 /// Traits for notedown
@@ -21,8 +23,11 @@ pub use self::{
 };
 
 pub mod utils {
+    pub use indexmap;
     pub use itertools;
-    pub use lsp_types;
     pub use text_utils;
-    pub use yggdrasil_shared::records::*;
+    #[cfg(feature = "lsp")]
+    pub use yggdrasil_shared::records::lsp_types;
+    #[cfg(feature = "lsp")]
+    pub use yggdrasil_shared::records::{LSPPosition, LSPRange, TextIndex};
 }
