@@ -46,15 +46,16 @@ impl Display for Delimiter {
     }
 }
 
-impl Debug for TextKind {
+impl Debug for TextSpan {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         match self {
             Self::Normal(s) => Debug::fmt(s, f),
+            Self::Raw(s) => Debug::fmt(s, f),
             Self::HTMLRawInline(s) => Debug::fmt(s, f),
             Self::Escaped(c) => {
                 write!(f, "TextNode::Escaped({})", c)
             }
-            Self::Emoji(c) => f.write_char(*c),
+            Self::Emoji(emoji) => write!(f, "TextNode::Emoji({})", emoji),
             Self::SoftNewline => f.write_str("TextNode::SoftNewline"),
             Self::HardNewline => f.write_str("TextNode::HardNewline"),
             Self::CheckBox(b) => {
@@ -67,7 +68,7 @@ impl Debug for TextKind {
     }
 }
 
-impl Display for TextKind {
+impl Display for TextSpan {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         match self {
             Self::Normal(_) => {
@@ -80,7 +81,7 @@ impl Display for TextKind {
                 f.write_char('\\')?;
                 f.write_char(*c)
             }
-            Self::Emoji(c) => f.write_char(*c),
+            Self::Emoji(emoji) => f.write_str(emoji),
             Self::SoftNewline => f.write_char('\n'),
             Self::HardNewline => f.write_char('\n'),
             Self::CheckBox(b) => match b {
@@ -88,6 +89,7 @@ impl Display for TextKind {
                 false => f.write_str("[ ]"),
             },
             Self::Empty => Ok(()),
+            Self::Raw(_) => Ok(()),
         }
     }
 }
